PCB Environment: LogFile Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Attributes
LogFile Class Reference

## Public Member Functions
std::ostream & | stream ()
const std::string & | getPath () const
void | setPath (const std::string_view)
void | redirect (LogFile &)
bool | isOwner () const
LogFile * | owner () const
void | ownFile ()
void | updateOwner ()

## Static Public Attributes
static constexpr const std::size_t | MaxSize = 32ull << 20

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Log.hpp